function GenericGetRadialStatsMod(RadialSite,RadialType,FileStartNum,FileCheckSwitch,YearToLoad)
%
%  GenericGetRadialStatsMod(RadialSite,RadialType,FileStartNum,FileCheckSwi
%  tch,YearToLoad);
%  21 May 2009 - done for the latest SHEL and PAFS radials (well, all since
%  July 2008)
%
%  if FileCheckSwitch is 1, the routine checks to see if the output file
%  exists before doing the calculations, so calculations are not repeated
%  if the routine is interrupted and then restarted.
%
%  PAFS site for latest set of radials added
%
%  This routine loads the radials already obtained, concatenates them (so we have one 
%  radial structure instead of many for each time), and calculates the
%  "first order" stats - basically checks for unique radials, etc.
%
%  YearToLoad added for the year 2006 for the local data
%
%  Monterey and Santa Cruz sites added - October 2008
%
%  SHEL site added - Nov 2008
%
switch upper(RadialType)
    case 'IDEAL'
        RadialType='Ideal';
    otherwise
        RadialType='Measured';
end
%
if exist('YearToLoad','var'),
    GlobalDirIn=cell(1,1);
    GlobalDirIn{1}=['/Users/chrishalle/Documents/CODARData/Radials/' upper(RadialSite) num2str(YearToLoad) '/MatlabForEddy/' RadialType];
    GlobalDirOut=['/Users/chrishalle/Documents/CODARData/Radials/' upper(RadialSite) num2str(YearToLoad) '/MatlabForEddy/' RadialType '/FirstOrderStats/'];
else
    GlobalDirIn=cell(1,1);
    GlobalDirIn{1}=['/Users/chrishalle/Documents/CODARData/Radials/' upper(RadialSite) '/MatlabForEddy/' RadialType];
    GlobalDirOut=['/Users/chrishalle/Documents/CODARData/Radials/' upper(RadialSite) '/MatlabForEddy/' RadialType '/FirstOrderStats/'];
end
%
if ~exist(GlobalDirOut,'dir'),
    %
    [SUCCESS,MESSAGE,MESSAGEID] = mkdir(GlobalDirOut);
    if ~SUCCESS,
        disp('creation of output directory failed')
        disp('routine ending')
        return;
    end
end
%
if exist('YearToLoad','var'),
    RadialSiteTem=[RadialSite num2str(YearToLoad)];
else
    RadialSiteTem=RadialSite;
end
%
switch upper(RadialSiteTem)
    case 'SLID'
        SiteCode={'SLID'};
        Spacing=1;  % in hours, just used to get time axis - clugey, based on old code
        RadialMaskFile={'/Users/chrishalle/Documents/CMHToolbox/NationalParkStudy/SLIDRadialMask.txt'}; % !!!!  change
        if isequal(RadialType,'Ideal'),
            StartDate=[2008 3 30 7];  % really only need to enter year and month of start times, but keep this way for ease
            EndDate=[2008 6 4 14];
        else
            StartDate=[2008 3 30 7];
            EndDate=[2008 6 4 14];
        end
    case 'COMM'
        SiteCode={'COMM'};
        Spacing=1;  % in hours
        RadialMaskFile={'/Users/chrishalle/Documents/CMHToolbox/NationalParkStudy/COMMRadMaskIn.txt'}; % !!!!  change
        if isequal(RadialType,'Ideal'),
            StartDate=[2006 5 31 19];
            EndDate=[2008 5 1 17];
        else
            StartDate=[2006 7 21 0];
            EndDate=[2008 5 1 17];
        end
    case 'MONT'
        SiteCode={'MONT'};
        Spacing=1;  % in hours
        RadialMaskFile={'/Users/chrishalle/Documents/CMHToolbox/NationalParkStudy/MONTRadMaskIn.txt'}; % !!!!  change
        if isequal(RadialType,'Ideal'),
            StartDate=[2006 6 6 22];
            EndDate=[2008 5 11 3];
        else
            StartDate=[2006 7 21 0];
            EndDate=[2008 4 30 22];
        end
    case 'FORT'
        SiteCode={'FORT'};
        Spacing=1;  % in hours
        RadialMaskFile={'/Users/chrishalle/Documents/CMHToolbox/NationalParkStudy/FORTRadMaskIn.txt'}; % !!!!  change
        if isequal(RadialType,'Ideal'),
            StartDate=[2006 8 1 15];
            EndDate=[2008 5 15 16];
        else
            StartDate=[2006 7 21 0];
            EndDate=[2008 5 15 16];
        end
    case 'BMLR'
        SiteCode={'BMLR'};
        Spacing=1;  % in hours
        RadialMaskFile={'/Users/chrishalle/Documents/CODARData/LongRangeNearBML/ProcessingInfo/BMLRRadialMask.txt'}; % !!!!  change
        if isequal(RadialType,'Ideal'),
            StartDate=[2007 2 3 20];
            EndDate=[2008 6 12 20];
        else
            StartDate=[2007 2 3 20];
            EndDate=[2008 6 12 20];
        end
%     case 'PAFS'
%         %
%         SiteCode={'PAFS'};
%         Spacing=1;  % in hours
%         RadialMaskFile={'/Users/chrishalle/Documents/CODARData/LongRangeNearBML/ProcessingInfo/MENDRadialMask.txt'}; % !!!!  change
%         if isequal(RadialType,'Ideal'),
%             StartDate=[2007 6 15 1];
%             EndDate=[2008 6 12 21];
%         else
%             StartDate=[2007 6 15 20];
%             EndDate=[2008 6 12 21];
%         end
    case 'PAFS'
        %
        SiteCode={'PAFS'};
        Spacing=1;  % in hours
        RadialMaskFile={'/Users/chrishalle/Documents/CODARData/Radials/MaskInfo/PAFSRadMaskInNoShadowZones.txt'}; % !!!!  change
        if isequal(RadialType,'Ideal'),
            StartDate=[2008 8 1 1];
            EndDate=[2009 5 4 14];
        else
            StartDate=[2008 7 28 21];  % these not valid - only using ideals for now
            EndDate=[2008 11 3 21];
        end
    case 'BML1'
        SiteCode={'BML1'};
        Spacing=1;  % in hours, just used to get time axis - clugey, based on old code
        RadialMaskFile={'/Users/chrishalle/Documents/CODARData/StandardRangeNearBML/ProcessingInfo/BMLRadMaskIn.txt'}; % !!!!  change
        if isequal(RadialType,'Ideal'),
            StartDate=[2007 1 1 0];
            EndDate=[2008 6 12 20];
        else
            StartDate=[2007 1 1 0];
            EndDate=[2008 6 12 20];
        end
    case 'GCVE'
        SiteCode={'GCve'};
        Spacing=1;  % in hours, just used to get time axis - clugey, based on old code
        RadialMaskFile={'/Users/chrishalle/Documents/CODARData/StandardRangeNearBML/ProcessingInfo/GCVERadMaskIn.txt'}; % !!!!  change
        if isequal(RadialType,'Ideal'),
            StartDate=[2007 3 8 6];
            EndDate=[2008 5 9 18];
        else
            StartDate=[2007 3 8 6];
            EndDate=[2008 5 9 18];
        end
    case 'PREY'
        SiteCode={'PRey'};
        Spacing=1;  % in hours, just used to get time axis - clugey, based on old code
        RadialMaskFile={'/Users/chrishalle/Documents/CODARData/StandardRangeNearBML/ProcessingInfo/PREYRadMaskIn.txt'}; % !!!!  change
        if isequal(RadialType,'Ideal'),
            StartDate=[2007 1 1 0];
            EndDate=[2008 6 12 22];
        else
            StartDate=[2007 1 1 0];
            EndDate=[2008 6 5 22];
        end
    case 'BML12006'
        %
        SiteCode={'BML1'};
        Spacing=1;  % in hours, just used to get time axis - clugey, based on old code
        RadialMaskFile={'/Users/chrishalle/Documents/CODARData/StandardRangeNearBML/ProcessingInfo/BMLRadMaskIn.txt'}; % !!!!  change
        if isequal(RadialType,'Ideal'),
            StartDate=[2006 1 1 8];
            EndDate=[2006 12 31 23];
        else
            StartDate=[2006 1 1 8];
            EndDate=[2006 12 31 23];
        end
    case 'GCVE2006'
        %
        SiteCode={'GCve'};
        Spacing=1;  % in hours, just used to get time axis - clugey, based on old code
        RadialMaskFile={'/Users/chrishalle/Documents/CODARData/StandardRangeNearBML/ProcessingInfo/GCVERadMaskIn.txt'}; % !!!!  change
        if isequal(RadialType,'Ideal'),
            StartDate=[2006 1 1 8];
            EndDate=[2006 11 18 20];
        else
            StartDate=[2006 1 1 8];
            EndDate=[2006 11 18 20];
        end
    case 'PREY2006'
        %
        SiteCode={'PRey'};
        Spacing=1;  % in hours, just used to get time axis - clugey, based on old code
        RadialMaskFile={'/Users/chrishalle/Documents/CODARData/StandardRangeNearBML/ProcessingInfo/PREYRadMaskIn.txt'}; % !!!!  change
        if isequal(RadialType,'Ideal'),
            StartDate=[2006 1 6 2];
            EndDate=[2006 12 31 23];
        else
            StartDate=[2006 1 6 2];
            EndDate=[2006 12 31 23];
        end
        %
        %  MONT BAY AND SCRZ SITES FOLLOW
        %
    case 'BIGC'
        SiteCode={'BIGC'};
        Spacing=1;  % in hours
        RadialMaskFile={'/Users/chrishalle/Documents/CMHToolbox/NationalParkStudy/BIGCRadMaskIn.txt'}; % !!!!  change
        if isequal(RadialType,'Ideal'),
            StartDate=[2006 3 16 0];
            EndDate=[2008 7 13 12];
        else
            StartDate=[2006 8 2 22];
            EndDate=[2006 7 13 12];
        end
        %
    case 'GCYN'
        SiteCode={'GCYN'};
        Spacing=1;  % in hours
        RadialMaskFile={'/Users/chrishalle/Documents/CODARData/StandardRangeNearBML/ProcessingInfo/PREYRadMaskIn.txt'}; % !!!!  change
        if isequal(RadialType,'Ideal'),
            StartDate=[2006 2 10 22];
            EndDate=[2008 8 14 20];
        else
            StartDate=[2007 8 6 20];
            EndDate=[2008 8 14 20];
        end
        %
    case 'MLML'
        SiteCode={'MLML'};
        Spacing=1;  % in hours
        RadialMaskFile={'/Users/chrishalle/Documents/CODARData/StandardRangeNearBML/ProcessingInfo/PREYRadMaskIn.txt'}; % !!!!  change
        if isequal(RadialType,'Ideal'),
            StartDate=[2006 11 16 2];
            EndDate=[2008 6 23 18];
        else
            StartDate=[2006 11 16 2];
            EndDate=[2008 6 23 18];
        end
        %
    case 'MLNG'
        SiteCode={'MLNG'};
        Spacing=1;  % in hours
        RadialMaskFile={'/Users/chrishalle/Documents/CODARData/StandardRangeNearBML/ProcessingInfo/PREYRadMaskIn.txt'}; % !!!!  change
        if isequal(RadialType,'Ideal'),
            StartDate=[2006 1 1 0];
            EndDate=[2006 11 16 0];
        else
            StartDate=[2006 1 1 0];
            EndDate=[2006 11 16 0];
        end
        %
    case 'NPGS'
        SiteCode={'NPGS'};
        Spacing=1;  % in hours
        RadialMaskFile={'/Users/chrishalle/Documents/CODARData/StandardRangeNearBML/ProcessingInfo/PREYRadMaskIn.txt'}; % !!!!  change
        if isequal(RadialType,'Ideal'),
            StartDate=[2006 1 1 0];
            EndDate=[2008 7 10 17];
        else
            StartDate=[2006 1 1 0];
            EndDate=[2008 7 10 17];
        end
        %
    case 'PESC'
        SiteCode={'PESC'};
        Spacing=1;  % in hours
        RadialMaskFile={'/Users/chrishalle/Documents/CMHToolbox/NationalParkStudy/PESCRadMaskIn.txt'}; % !!!!  change
        if isequal(RadialType,'Ideal'),
            StartDate=[2006 6 8 21];
            EndDate=[2008 8 11 18];
        else
            StartDate=[2007 3 12 18];
            EndDate=[2008 4 23 19];
        end
        %        
    case 'PPIN'
        SiteCode={'PPIN'};
        Spacing=1;  % in hours
        RadialMaskFile={'/Users/chrishalle/Documents/CODARData/StandardRangeNearBML/ProcessingInfo/PREYRadMaskIn.txt'}; % !!!!  change
        if isequal(RadialType,'Ideal'),
            StartDate=[2006 1 10 19];
            EndDate=[2008 8 22 22];
        else
            StartDate=[2006 1 10 19];
            EndDate=[2008 8 22 22];
        end
        %
    case 'PSLR'
        SiteCode={'PSLR'};
        Spacing=1;  % in hours
        RadialMaskFile={'/Users/chrishalle/Documents/CODARData/StandardRangeNearBML/ProcessingInfo/PREYRadMaskIn.txt'}; % !!!!  change
        if isequal(RadialType,'Ideal'),
            StartDate=[2007 11 16 0];
            EndDate=[2008 7 25 20];
        else
            StartDate=NaN;  % means no measured files
            EndDate=NaN;
        end
        %
    case 'PSUR'
        SiteCode={'PSUR'};
        Spacing=1;  % in hours
        RadialMaskFile={'/Users/chrishalle/Documents/CODARData/StandardRangeNearBML/ProcessingInfo/PREYRadMaskIn.txt'}; % !!!!  change
        if isequal(RadialType,'Ideal'),
            StartDate=[2006 1 1 0];
            EndDate=[2008 8 1 16];
        else
            StartDate=[2006 1 1 0];
            EndDate=[2007 12 22 19]; % did measured pattern go bad?
        end
        %
    case 'SCRZ'
        SiteCode={'SCRZ'};
        Spacing=1;  % in hours
        RadialMaskFile={'/Users/chrishalle/Documents/CODARData/StandardRangeNearBML/ProcessingInfo/PREYRadMaskIn.txt'}; % !!!!  change
        if isequal(RadialType,'Ideal'),
            StartDate=[2006 1 1 0];
            EndDate=[2008 5 21 19];
        else
            StartDate=[2006 1 1 0];
            EndDate=[2008 5 21 19];
        end
        %
    case 'SHEL'
        SiteCode={'SHEL'};
        Spacing=1;  % in hours
        RadialMaskFile={'/Users/chrishalle/Documents/CODARData/Radials/MaskInfo/SHELRadMaskInNoShadowZones.txt'}; % !!!!  change
        if isequal(RadialType,'Ideal'),
            StartDate=[2008 8 1 1];
            EndDate=[2009 5 4 14];
        else
            StartDate=NaN;
            EndDate=NaN;
        end
        %
    otherwise
        disp('other sites not set up yet')
        disp('routine ending')
end
%
LogFileName=[upper(RadialSite) 'RadialFirstOrderStats' datestr(clock,30) '.txt'];  % the log file
%
%  Set up the year / month time axis to load (will correspond to the file
%  names)
%
TemStart=datenum([StartDate 0 0]);
TemEnd=datenum([EndDate 0 0]);
TimeVect=TemStart:Spacing/24:TemEnd;
TemVec=datevec(TimeVect);
%
%  problem!!!! datevec routine sometimes gives 59 minutes and 60 seconds
%  instead of converting to the next hour....  check this.
%
temmark=find((TemVec(:,5)>58)&(TemVec(:,6)>58));
if numel(temmark)>0,
    disp('converting some times to next highest hour')
    disp('standard Matlab issue with datevec command')
    TemVec(temmark,4)=TemVec(temmark,4)+1;
    TemVec(temmark,5)=0;
    TemVec(temmark,6)=0;
end
%
TemVec=round(TemVec);
%
TemVecYearMonth=TemVec(:,1:2);
TemVecYearMonth=unique(TemVecYearMonth,'rows');
[NumMonths,NumCols]=size(TemVecYearMonth);
%
TemStr=['Number of Months To Process: ' num2str(NumMonths)];
AddLineToLog(GlobalDirOut,LogFileName,TemStr);
%
FileNamesIn=SetUpRadialFileNames(GlobalDirIn,SiteCode,RadialType,TemVecYearMonth);
%
StartClock=clock;
%
for jfile=FileStartNum:1:NumMonths,
    %
    YearMonthToProcess=TemVecYearMonth(jfile,:);
    %
    TemFileName=[upper(RadialSite) 'FirstOrderStatsRads' RadialType 'Y' num2str(YearMonthToProcess(1)) 'M' num2str(YearMonthToProcess(2)) '.mat'];
    %
    if FileCheckSwitch,
        cd(GlobalDirOut);
        if exist(TemFileName,'file'),
            FileProcessedAlready=1;
        else
            FileProcessedAlready=0;
        end
    else
        FileProcessedAlready=0;
    end
    %
    if ~FileProcessedAlready,
        %
        AddLineToLog(GlobalDirOut,LogFileName,'*****');
        TemStr=['Starting Processing With File Number' num2str(jfile)];
        AddLineToLog(GlobalDirOut,LogFileName,TemStr);
        AddLineToLog(GlobalDirOut,LogFileName,'*****');
        %
        FileFound=1;
        %
        try
            load(FileNamesIn{jfile});
            RorigCurrent=Rorig;
            clear Rorig
            %
            %  get the filenames associated with the loading, so that we can
            %  keep only the relevant portions later
            %
            NumRorigCurrent=numel(RorigCurrent);
            FilesLoadedCurrent=cell(NumRorigCurrent,1);
            for jfname=1:NumRorigCurrent,
                FilesLoadedCurrent{jfname}=char(RorigCurrent(jfname).FileName);
            end
            %
        catch
            FileFound=0;
        end
        %
        if FileFound,
            %
            %  Load the file before, if possible
            %
            if jfile>1,
                try
                    %
                    load(FileNamesIn{jfile-1});
                    RorigBefore=Rorig;
                    clear Rorig
                    %
                    DataBefore=ExtractData(RorigBefore,'LastMeasurement');
                    %
                    RorigCurrent=[DataBefore;RorigCurrent];
                    %
                    clear RorigBefore DataBefore
                    %
                catch
                    %  do nothing
                end
            end
            %
            %  Load the file after, if possible
            %
            if jfile<NumMonths,
                try
                    %
                    load(FileNamesIn{jfile+1});
                    RorigAfter=Rorig;
                    clear Rorig
                    %
                    DataAfter=ExtractData(RorigAfter,'FirstMeasurement');
                    %
                    RorigCurrent=[RorigCurrent;DataAfter];
                    %
                    clear RorigAfter DataAfter
                    %
                catch
                    %  do nothing
                end
            end
            %
            %  now calculate stats
            %
            [RadialStats,Rcat]=GetRadialStatistics2(RorigCurrent,RadialMaskFile,{SiteCode});
            %
            %  Keep only the data we want (extract only the month we would
            %  like)
            %
            [Rorig,RadialStats,Rcat]=ExtractRelevantMonthlyData(RorigCurrent,RadialStats,Rcat,FilesLoadedCurrent);
            %
            clear RorigCurrent
            %
            %  save the file
            %
            TemFileName=[upper(RadialSite) 'FirstOrderStatsRads' RadialType 'Y' num2str(YearMonthToProcess(1)) 'M' num2str(YearMonthToProcess(2)) '.mat'];
            %
            cd(GlobalDirOut);
            %
            save(TemFileName,'Rorig','RadialStats','Rcat');
            %
            AddLineToLog(GlobalDirOut,LogFileName,'*****');
            TemStr=['Year ' num2str(YearMonthToProcess(1)) ' Month ' num2str(YearMonthToProcess(2)) ' Processed'];
            AddLineToLog(GlobalDirOut,LogFileName,TemStr);
            disp(TemStr)
            TemStr=['Month Number ' num2str(jfile)];
            AddLineToLog(GlobalDirOut,LogFileName,TemStr);
            AddLineToLog(GlobalDirOut,LogFileName,datestr(clock));
            %
            ElapsedTime=etime(clock,StartClock);
            ElapsedTime=(1/60)*ElapsedTime;
            %
            TemStr=['Elapsed Time in minutes since FileStartNum: ' num2str(ElapsedTime)];
            AddLineToLog(GlobalDirOut,LogFileName,TemStr);
            disp(TemStr)
            %
            AddLineToLog(GlobalDirOut,LogFileName,'*****');
            %
            clear Rorig RadialStats Rcat
            %
        else
            AddLineToLog(GlobalDirOut,LogFileName,'*****');
            TemStr=['Year ' num2str(YearMonthToProcess(1)) ' Month ' num2str(YearMonthToProcess(2)) ' NOT FOUND !!!!'];
            AddLineToLog(GlobalDirOut,LogFileName,TemStr);
            disp(TemStr)
            TemStr=['Month Number ' num2str(jfile)];
            AddLineToLog(GlobalDirOut,LogFileName,TemStr);
            AddLineToLog(GlobalDirOut,LogFileName,datestr(clock));
        end
        %
    else
        %
        AddLineToLog(GlobalDirOut,LogFileName,'*****');
        TemStr=['Year ' num2str(YearMonthToProcess(1)) ' Month ' num2str(YearMonthToProcess(2)) ' Already Processed'];
        AddLineToLog(GlobalDirOut,LogFileName,TemStr);
        disp(TemStr)
        TemStr=['Month Number ' num2str(jfile)];
        AddLineToLog(GlobalDirOut,LogFileName,TemStr);
        AddLineToLog(GlobalDirOut,LogFileName,datestr(clock));
        %
    end
end
%
%  the routine is done
%
return;
%
function [FileNamesOut]=SetUpRadialFileNames(DirIn,SiteCode,RadialType,YearMonthMatrix)
%
%  [FileNamesOut]=SetUpRadialFileNames(DirIn,SiteCode,RadialType,YearM
%  onthMatrix);
%
%  To set up the Matlab file names for input
%
%  YearMonthMatrix has two columns corresponding to the month and the year
%
[NumTimes,numcols]=size(YearMonthMatrix);
FileNamesOut=cell(NumTimes,1);
%
DirSetUp=repmat(DirIn,NumTimes,1);
SiteSetUp=repmat(SiteCode,NumTimes,1);
RadsSetUp=repmat('Rads',NumTimes,1);
RadTypeSetUp=repmat(RadialType,NumTimes,1);
YearCharMat=repmat('Y',NumTimes,1);
MonthCharMat=repmat('M',NumTimes,1);
%
YearMat=cellstr(num2str(YearMonthMatrix(:,1)));
MonthMat=cellstr(num2str(YearMonthMatrix(:,2)));
%
%  the above pads the months with zeros!!!!!  Not Good.
%
%  Clugey fix
%
for jmonth=1:numel(MonthMat),
    if YearMonthMatrix(jmonth,2)<=9,
        MonthMat{jmonth}=num2str(YearMonthMatrix(jmonth,2));
    end
end
%
SuffixMat=repmat('.mat',NumTimes,1);
%
TemNames=strcat(SiteSetUp,RadsSetUp,RadTypeSetUp,YearCharMat,YearMat,MonthCharMat,MonthMat,SuffixMat);
FileNamesOut=fullfile_multiple(DirSetUp,TemNames);
%
return;
%
function [DataOut]=ExtractData(RadialsIn,FirstLastSwitch)
%
%  [DataOut]=ExtractData(RadialsIn,FirstLastSwitch);
%
%  to extract the first or last radial structure (so we can append when
%  calculating the first order radial statistics)
%
%  Assumes last measurement wanted if first measurement switch not
%  specified (or thrown incorrectly)
%
%  Get the times associated with the radial structure.  Quick but crude -
%  not assuming in time order here for some reason.
%
TimesOfRadials=NaN*ones(numel(RadialsIn),1);
%
for jrad=1:numel(RadialsIn),
    TimesOfRadials(jrad)=RadialsIn(jrad).TimeStamp;
end
%
switch upper(FirstLastSwitch)
    case 'FIRSTMEASUREMENT'
        [TimeMark,PosMark]=nanmin(TimesOfRadials);
    otherwise
        [TimeMark,PosMark]=nanmax(TimesOfRadials);
end
%
DataOut=RadialsIn(PosMark);
%
%  the routine is done
%
return;
%
function [RorigOut,RadialStatsOut,RcatOut]=ExtractRelevantMonthlyData(RorigIn,RadialStatsIn,RcatIn,FileSetToKeep)
%
%  [RorigOut,RadialStatsOut,RcatOut]=ExtractRelevantMonthlyData(RorigIn,Rad
%  ialStatsIn,RcatIn,FileSetToKeep);
%
%  FileSetToKeep is a cell array of cells, contains the file names that were originally loaded.
%  Used to trim the arrays to what we would like
%
%  Step 1 - obtain the total list of files from RorigIn
%
NumRorigIn=numel(RorigIn);
RorigInFiles=cell(NumRorigIn,1);
for jfname=1:NumRorigIn,
    RorigInFiles{jfname}=char(RorigIn(jfname).FileName);
end
%
%  now find the indices of the files we want to keep
%
[C,ExtractIndices,IB]=intersect(RorigInFiles,FileSetToKeep);
%
%  Now, this will not matter if doing one site at a time....  but in case
%  we expand, add a sorting function to keep the indices in order
%
ExtractIndices=sort(ExtractIndices,'ascend');
%
if numel(ExtractIndices)<1,
    RorigOut=NaN;
else
    RorigOut=RorigIn(ExtractIndices);
end
clear ExtractIndices TimesOfRadials
%
%  Step 2 - Get the file names from Rcat
%
[temrows,temcols]=size(RcatIn.FileName);
if temcols>temrows,
    RcatFiles=RcatIn.FileName';
else
    RcatFiles=RcatIn.FileName;
end
%
[C,ExtractIndices,IB]=intersect(RcatFiles,FileSetToKeep);
%
%  Now, this will not matter if doing one site at a time....  but in case
%  we expand, add a sorting function to keep the indices in order
%
ExtractIndices=sort(ExtractIndices,'ascend');
%
if numel(ExtractIndices)<1,
    RcatOut=NaN;
else
    [NumPoints,NumCols]=size(RcatIn.LonLat);
    RcatOut=subsrefRADIAL(RcatIn,[1:NumPoints],ExtractIndices);
end
clear ExtractIndices TimesOfRadials
%
%  Step 3 - Extract the relevant sections from RadialStats.
%  Should match Rcat, but do separately in case.
%
[C,ExtractIndices,IB]=intersect(RadialStatsIn.FileNames,FileSetToKeep);
%
ExtractIndices=sort(ExtractIndices,'ascend');
%
if numel(ExtractIndices)<1,
    RadialStatsOut=NaN;
else
    RadialStatsOut=ExtractFieldsFromStruct(RadialStatsIn,ExtractIndices,1);
end
%
%  the routine is done
%
return;
%
