function GenericSHELPAFSTotalsPartAmod(RadialType,FileStartNum,FileCreatedSwitch,DebugMode)
%
%  GenericSHELPAFSTotalsPartAmod(RadialType,FileStartNum,FileCreatedSwitch,DebugMode);
%
%
%  DegbugMode=1 means just to run for month 2 of all the months
%  DegbugMode=0 means run for all of the months
%
%  FileCreatedSwitch = 1 means that we check to see if the files exist already, and if so
%  we don't need to do the calculations again. FileCreatedSwitch = 0 means that we 
%  do not need this switch
%
%  done for the new set of measurements for SHEL and PAFS (Summer 2008 - May 2009)
%
%  modified for SHEL and PAFS.... savng various steps now, but shouldn;t
%  need to after full debugging carried out.  Very inefficient.
%
%  Gets the initial set of cleaned totals using GDOP and the first set of
%  temporal statistics.  Uses the second order cleaned radials.
% 
%  Uses 5 km resolution.
%
%  This is just for the long range totals at the moment.
%
%  Gets cleaned totals.  Reporocesses using new totls grids, gets second order
%  stats for totals, and cleans according to those.  Could use already saved totals to
%  do, but would be more work modifying structures than is probably worth
%  it.
%
%  ResSwitch is 5 for 5 km, 10 for 10 km
%
%  reprocesses to get totals.  Could set up to clean already processed
%  totals, but this was will be easier if we want to screen accoriding to
%  NumRads later.  Also easier for automatic processing.
%
%  Set up to use less severe geo cleaning as well - GDOPMaxOrthog of 2.5
%
switch upper(RadialType)
    case 'IDEAL'
        RadialType='Ideal';
    otherwise
        RadialType='Measured';
end
%
GlobalDirIn=cell(2,1);
GlobalDirIn{1}=['/Users/chrishalle/Documents/CODARData/Radials/SHEL/MatlabForEddy/' RadialType '/CleanedSecondOrder/'];
GlobalDirIn{2}=['/Users/chrishalle/Documents/CODARData/Radials/PAFS/MatlabForEddy/' RadialType '/CleanedSecondOrder/'];
%
SiteCodes=cell(2,1);
SiteCodes{1}=['SHEL'];
SiteCodes{2}=['PAFS'];
%
GlobalDirOut=['/Users/chrishalle/Documents/CODARData/Totals/SHELPAFSEddy/MatlabForEddy/TotalsSetA/' RadialType '/'];
%
if ~exist(GlobalDirOut,'dir'),
    %
    [SUCCESS,MESSAGE,MESSAGEID] = mkdir(GlobalDirOut);
    if ~SUCCESS,
        disp('creation of output directory failed')
        disp('routine ending')
        return;
    end
end
%
LogFileName=['SHELPAFSTotalsPartA' datestr(clock,30) '.txt'];  % the log file
%
%  enter start date and end date for processing
%
StartDate=[2008 8 1 1];  % really only need to enter year and month of start times, but keep this way for ease
EndDate=[2009 5 4 14];   % ideal and measured start / end times roughly the same for BMLR and PAFS
%
%  Radial Mask Files
%
RadialMaskFiles={'/Users/chrishalle/Documents/CODARData/Radials/MaskInfo/SHELRadMaskInNoShadowZones.txt',...
    '/Users/chrishalle/Documents/CODARData/Radials/MaskInfo/PAFSRadMaskInNoShadowZones.txt'};
%
%  Grid File
%
GridFile=['/Users/chrishalle/Documents/CODARData/Totals/SHELPAFSEddy/ProcessingInfo/InitialPAFSSHELGrid.txt'];
%
[GridForTotals,fn,c] = loadDataFileWithChecks(GridFile);
%
if c >= 100
    disp( 'Could not find the grid.' );
    disp('total generation aborted')
    return;
end
%
AverageInterval=1;  % for hourly processing
TimeWindow=(0.49999*AverageInterval)/24;  % to take care of roundoff
%
MaxGapTDiff=4;
PerCovWindowSearch=8;  % two parameters for calculating stats
%CleaningParameters={'No',[0.003],'MinTotDiff','AboveBad';'No',[35],'PerCovTyp','BelowBad'};
CleaningParameters={'No',[0.003],'MinTotDiff','AboveBad';'No',[35],'PerCovMin','BelowBad'};
%
%  Get years and months to load
%
Spacing=1;
TemStart=datenum([StartDate 0 0]);
TemEnd=datenum([EndDate 0 0]);
TimeVect=TemStart:Spacing/24:TemEnd;
TemVec=datevec(TimeVect);
%
%  problem!!!! datevec routine sometimes gives 59 minutes and 60 seconds
%  instead of converting to the next hour....  check this.
%
temmark=find((TemVec(:,5)>58)&(TemVec(:,6)>58));
if numel(temmark)>0,
    disp('converting some times to next highest hour')
    disp('standard Matlab issue with datevec command')
    TemVec(temmark,4)=TemVec(temmark,4)+1;
    TemVec(temmark,5)=0;
    TemVec(temmark,6)=0;
end
%
TemVec=round(TemVec);
%
TemVecYearMonth=TemVec(:,1:2);
TemVecYearMonth=unique(TemVecYearMonth,'rows');
[NumMonths,NumCols]=size(TemVecYearMonth);
%
%  Method:  Loop through, for each site, load the file for a given month.
%  Load the files for the month before and after, if possible.
%  Extract the individual timestamps into individual radial structures so I can toss everthing into the same Rcat
%  routine (not really necessary, but will take care of the off-chance that
%  the different months have different grid structures?)
%
%  Do for each site.
%
%  Toss the whole mess into the concat routine.
%
%  Get the totals, despike.
%
%  Extract the relevant monthly totals.
%
%  Perform temporal qa/qc.  Save.
%
%
TemStr=['Number of Months To Process: ' num2str(NumMonths)];
AddLineToLog(GlobalDirOut,LogFileName,TemStr);
%
if DebugMode,
     StartFileProc=2;
     EndFileProc=2;
else
    StartFileProc=FileStartNum;
    EndFileProc=NumMonths;
end
%
for jmonth=StartFileProc:EndFileProc,
    %
    YearMonthToProcess=TemVecYearMonth(jmonth,:);
    %
    if isequal(jmonth,StartFileProc),
        StartClock=clock;
    end
    %
    %  now check to see if the file exists already - means that we do not have to step through the rest of the sequence
    %
    PerformCalculations=1;
    %
    if FileCreatedSwitch,
        %
        TemFileName=['SHELPAFSTotalsPartA' RadialType 'Y' num2str(YearMonthToProcess(1)) 'M' num2str(YearMonthToProcess(2)) '.mat'];
        %
        cd(GlobalDirOut);
        %
        if exist(TemFileName,'file'),  % !!! check syntax
            PerformCalculations=0;
        end
    end
    %
    if PerformCalculations,
        %
    AddLineToLog(GlobalDirOut,LogFileName,'*****');
    TemStr=['Starting Processing With File Number' num2str(jmonth)];
    AddLineToLog(GlobalDirOut,LogFileName,TemStr);
    AddLineToLog(GlobalDirOut,LogFileName,'*****');
    %
    RadialDataToUse=LoadDataFromSites(GlobalDirIn,SiteCodes,RadialType,TemVecYearMonth,jmonth,PerCovWindowSearch*2);  % load twice the length
    %  before and after PerCovWindowSearch
    %
    %  the data has been loaded, data from the months before and after have
    %  been loaded, radials have been concatenated into their respective
    %  sites, but not masked.
    %
    TemStr=['Month Number: ' num2str(jmonth) ', ' RadialType 'Radial Data Loaded'];
    AddLineToLog(GlobalDirOut,LogFileName,TemStr);
    disp(TemStr)
    %
    MaxTimeRead=datenum([2006 1 1 0 0 0]);
    MinTimeRead=now+10;
    %
    for k=1:numel(RadialDataToUse),
        MinTimeRead=min([nanmin(RadialDataToUse(k).TimeStamp) MinTimeRead]);
        MaxTimeRead=max([nanmax(RadialDataToUse(k).TimeStamp) MaxTimeRead]);
    end
    %
    TemStr=['Min Radial Time Read: ' datestr(MinTimeRead,0)];
    AddLineToLog(GlobalDirOut,LogFileName,TemStr);
    TemStr=['Max Radial Time Read: ' datestr(MaxTimeRead,0)];
    AddLineToLog(GlobalDirOut,LogFileName,TemStr);
    %    
    RadialDataToUse=CleanMaskInterp(RadialDataToUse);  % using a cutoff of 200 cm/s, just screening for too large a vel
    %
    %  mask the radial data (in case, s/b already, but....)
    %
    for k=1:numel(RadialDataToUse),  % we only have two sites here - BMLR and MEND
        if isequal(RadialDataToUse(k).SiteName,'SHEL'),
            [RcatMask(k),II{k}]=maskRadials(RadialDataToUse(k),RadialMaskFiles{1},true);
        else
            [RcatMask(k),II{k}]=maskRadials(RadialDataToUse(k),RadialMaskFiles{2},true);
        end
    end
    %
    TemStr=['Month Number: ' num2str(jmonth) ', Radial Data Masked'];
    AddLineToLog(GlobalDirOut,LogFileName,TemStr);
    disp(TemStr)
    %
    clear RadialDataToUse
    %
    %  Find the time stamps to calculate totals for
    %
    TimeStampToUse=GetTotalTimeStamp(TemVecYearMonth,jmonth,PerCovWindowSearch*2);  % get time stamps to match what we got from the radials
    %  - we might not always have all radial data to match - o.k.
    %
    [TUVorig,RTUV]=makeTotals(RcatMask,'Grid',GridForTotals,'TimeStamp',TimeStampToUse, ...
        'spatthresh',6, ...
        'tempthresh',TimeWindow, ...
        'CreationInfo','Chris Halle - SHELPAFSEddy', ...
        'DomainName','SHELPAFS' );
    %
    TemStr=['Month Number: ' num2str(jmonth) ', Totals Calculated'];
    AddLineToLog(GlobalDirOut,LogFileName,TemStr);
    disp(TemStr)
    %
    [TUVorig,I] = cleanTotals( TUVorig, 150,{'GDOPMaxOrthog','TotalErrors',2.5});  % 150 cm/s limit
    %
    TemStr=['Month Number: ' num2str(jmonth) ', Totals GDOP screened'];
    AddLineToLog(GlobalDirOut,LogFileName,TemStr);
    disp(TemStr)
    %
    [TUVorig]=GetHFTemporalStats(TUVorig,MaxGapTDiff,PerCovWindowSearch);
    %
    TemStr=['Month Number: ' num2str(jmonth) ', Temporal Stats Calculated'];
    AddLineToLog(GlobalDirOut,LogFileName,TemStr);
    disp(TemStr)
    %    
    [TUVorig]=CleanHFTemporalStats(TUVorig,CleaningParameters);
    %
    TemStr=['Month Number: ' num2str(jmonth) ', Temporal Stats Cleaned'];
    AddLineToLog(GlobalDirOut,LogFileName,TemStr);
    disp(TemStr)
    %
    [TUVorig]=ExtractRelevantMonthlyData(TUVorig,TemVecYearMonth,jmonth);
    %
    TemStr=['Month Number: ' num2str(jmonth) ', Appropriate Monthly Data Extracted'];
    AddLineToLog(GlobalDirOut,LogFileName,TemStr);
    disp(TemStr)
    %
    %  now save the file
    %
    TemFileName=['SHELPAFSTotalsPartA' RadialType 'Y' num2str(YearMonthToProcess(1)) 'M' num2str(YearMonthToProcess(2)) '.mat'];
    %
    cd(GlobalDirOut);
    %
    save(TemFileName,'TUVorig');
    %
    pause(2);
    %
    AddLineToLog(GlobalDirOut,LogFileName,'*****');
    TemStr=['Year ' num2str(YearMonthToProcess(1)) ' Month ' num2str(YearMonthToProcess(2)) ' Processed'];
    AddLineToLog(GlobalDirOut,LogFileName,TemStr);
    disp(TemStr)
    TemStr=['Month Number ' num2str(jmonth)];
    AddLineToLog(GlobalDirOut,LogFileName,TemStr);
    AddLineToLog(GlobalDirOut,LogFileName,datestr(clock));
    %
    ElapsedTime=etime(clock,StartClock);
    ElapsedTime=(1/60)*ElapsedTime;
    %
    TemStr=['Elapsed Time in minutes since FileStartNum: ' num2str(ElapsedTime)];
    AddLineToLog(GlobalDirOut,LogFileName,TemStr);
    disp(TemStr)
    %
    AddLineToLog(GlobalDirOut,LogFileName,'*****');
    %
    clear TUVorig RcatMask
    %
end %  !!!  added for the PerformCalculationsCheck
end
%
%  the routine is done
%
return;
%
function [RadialDataToUse]=LoadDataFromSites(GlobalDirIn,SiteCodes,RadType,YearMonthsList,MonthNumToLoad,HoursBeforeAndAfter)
%
%  [RadialDataToUse]=LoadDataFromSites(GlobalDirIn,SiteCodes,RadType,YearMo
%  nthsList,MonthNumToLoad,HoursBeforeAndAfter);
%
%  load the month required
%
[NumMonths,ncols]=size(YearMonthsList);
%
YearMonthToLoad=YearMonthsList(MonthNumToLoad,:);
%
DataFoundYet=0;
%
for jdir=1:numel(GlobalDirIn),
    %
    cd(GlobalDirIn{jdir});
    %
    TemFileName=[upper(SiteCodes{jdir}) 'CleanSecOrderRads' RadType 'Y' num2str(YearMonthToLoad(1)) 'M' num2str(YearMonthToLoad(2)) '.mat'];
    %
    try
        %
        load(TemFileName);
        %
        %  remove the stats field to be consistent with later structures
        %
        if isfield(Rcat,'TempStats'),
            Rcat=rmfield(Rcat,'TempStats');
        end
        %
        if isequal(DataFoundYet,0),
            %
            RadialDataToUse=Rcat;
            DataFoundYet=1;
        else
            RadialDataToUse=[RadialDataToUse;Rcat];
        end
        %
    catch
        %
        %  go to next file
        %
    end
end
%
%  Load the months before, if possible
%
if MonthNumToLoad>1,
    %
    YearMonthToLoad=YearMonthsList(MonthNumToLoad-1,:);
    %
    for jdir=1:numel(GlobalDirIn),
        %
        cd(GlobalDirIn{jdir});
        %
        TemFileName=[upper(SiteCodes{jdir}) 'CleanSecOrderRads' RadType 'Y' num2str(YearMonthToLoad(1)) 'M' num2str(YearMonthToLoad(2)) '.mat'];
        %
        try
            %
            load(TemFileName);
            %
            DataBefore=ExtractRcatData(Rcat,'LastMeasurements',HoursBeforeAndAfter,YearMonthToLoad);
            %
            clear Rcat
            %
            if isequal(DataFoundYet,0),
                %
                RadialDataToUse=DataBefore;
                DataFoundYet=1;
            else
                RadialDataToUse=[DataBefore;RadialDataToUse];
            end
            %
        catch
            %
            %  go to next file
            %
        end
    end
end
%
%  Load the months after, if possible
%
if MonthNumToLoad<NumMonths,
    %
    YearMonthToLoad=YearMonthsList(MonthNumToLoad+1,:);
    %
    for jdir=1:numel(GlobalDirIn),
        %
        cd(GlobalDirIn{jdir});
        %
        TemFileName=[upper(SiteCodes{jdir}) 'CleanSecOrderRads' RadType 'Y' num2str(YearMonthToLoad(1)) 'M' num2str(YearMonthToLoad(2)) '.mat'];
        %
        try
            %
            load(TemFileName);
            %
            DataAfter=ExtractRcatData(Rcat,'FirstMeasurements',HoursBeforeAndAfter,YearMonthToLoad);
            %
            clear Rcat
            %
            if isequal(DataFoundYet,0),
                %
                RadialDataToUse=DataAfter;
                DataFoundYet=1;
            else
                RadialDataToUse=[RadialDataToUse;DataAfter];
            end
            %
        catch
            %
            %  go to next file
            %
        end
    end
end
%
%  removing the stats field is redundant here, but include anyway (so we
%  can include this routine easily in other programs).  Including the
%  stats field causes the concatenation program to bomb.
%
if exist('RadialDataToUse','var'), % means we found some data
    if isfield(RadialDataToUse,'TempStats'),
        RadialDataToUse=rmfield(RadialDataToUse,'TempStats');
    end
    %
    %  loop through, strip empty structures.  Done here (before
    %  concatenation) to supress warning messages that would occur during
    %  concatenation if left untiul afterward
    %
    StructFound=0;
    for jcat=1:numel(RadialDataToUse),
        if ~isequal(RadialDataToUse(jcat).SiteName,''),
            StructFound=StructFound+1;
            if isequal(StructFound,1),
                IndexToExtract=jcat;
            else
                IndexToExtract=[IndexToExtract;jcat];
            end
        end
    end
    %
    if numel(IndexToExtract)>0,
        RadialDataToUse=RadialDataToUse(IndexToExtract);
        RadialDataToUse=temporalConcatRadials(RadialDataToUse,0.001,0.49,0.49,0.5 );
    else
        RadialDataToUse=RADIALstruct(1);  % return an empty radial structure if we didn't find any data
    end
    %
else
    RadialDataToUse=RADIALstruct(1);  % return an empty radial structure if we didn't find any data
end
%
%  the routine is done
%
return;
%
function [RcatOut]=ExtractRcatData(RcatIn,FirstOrLastSwitch,HoursToExtract,YearMonthToUse)
%
% [RcatOut]=ExtractRcatData(RcatIn,FirstOrLastSwitch,HoursToExtract,YearMonthToUse);
%
%  To extract data at the beginning or the end of a given month -
%  interfaces with the LoadDataFromSites routine
%
%  Get the time matrix and the year/month of the data passed to the routine
%
%  YearMonthToUse is somewhat redundant here, as we load a timestamp in the
%   Rcat data and can extract the month.  Keep in case at some point we end
%   up loading slighty more than one month - will save rewriting the
%   routine later.
%
%  Step 1 - Find the timestamps to extract
%
switch upper(FirstOrLastSwitch)
    case 'FIRSTMEASUREMENTS'
        TimeMarkStart=datenum([YearMonthToUse(1) YearMonthToUse(2) 1 0 0 0]);
        TimeMarkEnd=TimeMarkStart+(HoursToExtract/24);
    case 'LASTMEASUREMENTS'
        TimeMarkEnd=datenum([YearMonthToUse(1) YearMonthToUse(2)+1 1 0 0 0]);  % month wraparound during year changes 
        %is o.k. for datenum
        TimeMarkEnd=TimeMarkEnd-(1/24); %subtract one hour to get the end of the month we want
        TimeMarkStart=TimeMarkEnd-(HoursToExtract/24);
end
%
%  find the indices we need
%
TimeIndices=find((RcatIn.TimeStamp>=TimeMarkStart)&(RcatIn.TimeStamp<=TimeMarkEnd));
%
if numel(TimeIndices)>0,
    %
    [NumPoints,NumTimes]=size(RcatIn.RadComp);
    %
    if isfield(RcatIn,'TempStats'),
        RcatIn=rmfield(RcatIn,'TempStats');
    end
    %
    RcatOut=subsrefRADIAL(RcatIn,[1:NumPoints],TimeIndices);
    %
else
    RcatOut=RADIALstruct(1);  % return an empty radial structure if we didn't find any data
end
%
%  the routine is done
%
return;
%
function [TimeStampOut]=GetTotalTimeStamp(YearsMonthsIn,MonthNumber,HoursBeforeAndAfter)
%
%  [TimeStampOut]=GetTotalTimeStamp(YearsMonthsIn,MonthNumber,HoursBeforeAn
%  dAfter);
%
%  Gets the hourly time stamp to derive the totals, for the current month
%  and "HoursBeforeAndAfter" on either end
%
[NumMonths,ncols]=size(YearsMonthsIn);
CurrentYearMonth=YearsMonthsIn(MonthNumber,:);
TimeStart=datenum([CurrentYearMonth(1) CurrentYearMonth(2) 1 0 0 0]);
if MonthNumber>1,
    TimeStart=TimeStart-(HoursBeforeAndAfter/24);
end
TimeEnd=datenum([CurrentYearMonth(1) CurrentYearMonth(2)+1 1 0 0 0]);
TimeEnd=TimeEnd-(1/24);  % want time in  the current month, not the first hour of the next month
%  wraparound of months o.k. (can put year 2007 month 13 to get year 2008
%  month 1)
%
if MonthNumber<NumMonths,
    TimeEnd=TimeEnd+(HoursBeforeAndAfter/24);
end
%
TemTime=TimeStart:(1/24):TimeEnd;
if max(TemTime)<TimeEnd, % in case roundoff gets us
    TemTime=[TemTime TimeEnd];
end
%
% the following part of the routine (until the return statement) is also in case roundoff gets us.  
% Probably overkill, but that's o.k.
%
TemVec=datevec(TemTime);
%
%  problem!!!! datevec routine sometimes gives 59 minutes and 60 seconds
%  instead of converting to the next hour....  check this.
%
temmark=find((TemVec(:,5)>58)&(TemVec(:,6)>58));
if numel(temmark)>0,
    disp('converting some times to next highest hour')
    disp('standard Matlab issue with datevec command')
    TemVec(temmark,4)=TemVec(temmark,4)+1;
    TemVec(temmark,5)=0;
    TemVec(temmark,6)=0;
end
%
TemVec=round(TemVec);
%
TimeStampOut=datenum(TemVec);
TimeStampOut=TimeStampOut';
%
return;
%
function [RInterp]=CleanMaskInterp(Rcat)
%
%  [RInterp]=CleanMaskInterp(Rcat);
%
%
% clean, mask and interpolate radials !!!! no - just cleaning
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PROBLEM: We can no longer be certain of ordering of radials after
% temporalConcatRadials because (a) it sorts the names with unique and
% (b) if there are empties then this may disorder the list of sites (a
% more fundamental problem).
% SOLUTION: Use on-the-fly structure indexing to pick out correct
% cutoffs, masks, etc.  The advantage of this is that it is very explicit
% which parameters go with which sites.  The disadvantage is that you
% have to do each site separately.
%
% For cleaning
cutoff=200;  %  I will use 150 cm/s instead of 100 cm/s here.....
%
%  using the same cutoff for both sites, so should be o.k., do not need to
%  loop through and check.  Would be different if we also had to mask
%
for k = 1:numel(Rcat)
  % Clean large radials
  [Rclean(k),I{k}]=cleanRadials(Rcat(k),cutoff);
end
%
RInterp=Rclean;
%
return;
%
function [TUV]=ExtractRelevantMonthlyData(TUV,YearMonthsVector,MonthNumber)
%
%  [TUV]=ExtractRelevantMonthlyData(TUV,YearMonthsVector,MonthNumber);
%
%  This function extracts the monthly totals data that we want to save
%
%  Difficulty:  We have a stats field in the totals data that the standard
%  extraction routine cannot handle.  We should probably extract
%  information from the stats as well.
%
%  Get the number of spatial points, and the indices of the times to extract
%
[NumPoints,NumTimes]=size(TUV.U);
%
TemVec=datevec(TUV.TimeStamp);
%
%  problem!!!! datevec routine sometimes gives 59 minutes and 60 seconds
%  instead of converting to the next hour....  check this.
%
temmark=find((TemVec(:,5)>58)&(TemVec(:,6)>58));
if numel(temmark)>0,
    disp('converting some times to next highest hour')
    disp('standard Matlab issue with datevec command')
    TemVec(temmark,4)=TemVec(temmark,4)+1;
    TemVec(temmark,5)=0;
    TemVec(temmark,6)=0;
end
%
TemVec=round(TemVec);
%
YearMonthToExtract=YearMonthsVector(MonthNumber,:);
%
TimeIndex=find(ismember(TemVec(:,1:2),YearMonthToExtract,'rows'));
if numel(TimeIndex)>0,
    TimeIndex=TimeIndex';
end
%
if numel(TimeIndex)<1,
    %
    %  we do not have any data.  Return an empty totals structure
    %
    TUV = TUVstruct([1 1]);
    %
end
%
%  we need to check if the stats field is there.  If it is, remove it,
%  parse the totals, parse the stats, and reconstruct.
%
if isfield(TUV,'TempStats'),
    TUVStripped=rmfield(TUV,'TempStats');
    TUVStats=TUV.TempStats;
    TUVStripped=subsrefTUV(TUVStripped,[1:NumPoints],TimeIndex);
else
    TUVStripped=subsrefTUV(TUV,[1:NumPoints],TimeIndex);
end
%
clear TUV
%
if exist('TUVStats','var'),
    %
    StatNames=fieldnames(TUVStats);
    %
    for jstat=1:numel(StatNames),
        %
        eval(['TemSer=TUVStats.' StatNames{jstat} ';'])
        TemSer=TemSer(:,TimeIndex);
        eval(['TUVStats.' StatNames{jstat} '=TemSer;'])
        %
    end
end
%
if exist('TUVStats','var'),
    %
    TUV=TUVStripped;
    TUV.TempStats=TUVStats;
else
    TUV=TUVStripped;
end
%
clear TUVStripped TUVStats
%
%  the routine is done
%
return;
%
